package com.jjt.biz.service.impl;

import java.util.List;
import org.springframework.stereotype.Service;
import com.jjt.biz.mapper.TwinDeviceYhjMapper;
import com.jjt.biz.domain.TwinDeviceYhj;
import com.jjt.biz.service.ITwinDeviceYhjService;
import javax.annotation.Resource;

/**
 * 印花机设备管理Service业务层处理
 *
 * @author wukai
 * @date 2025-03-06
 */
@Service
public class TwinDeviceYhjServiceImpl implements ITwinDeviceYhjService {
    @Resource
    private TwinDeviceYhjMapper twinDeviceYhjMapper;

    /**
     * 查询印花机设备管理
     *
     * @param deviceId 印花机设备管理主键
     * @return 印花机设备管理
     */
    @Override
    public TwinDeviceYhj selectTwinDeviceYhjByDeviceId(Long deviceId) {
        return twinDeviceYhjMapper.selectTwinDeviceYhjByDeviceId(deviceId);
    }

    /**
     * 查询印花机设备管理列表
     *
     * @param twinDeviceYhj 印花机设备管理
     * @return 印花机设备管理
     */
    @Override
    public List<TwinDeviceYhj> selectTwinDeviceYhjList(TwinDeviceYhj twinDeviceYhj) {
        return twinDeviceYhjMapper.selectTwinDeviceYhjList(twinDeviceYhj);
    }

    /**
     * 新增印花机设备管理
     *
     * @param twinDeviceYhj 印花机设备管理
     * @return 结果
     */
    @Override
    public int insertTwinDeviceYhj(TwinDeviceYhj twinDeviceYhj) {
            return twinDeviceYhjMapper.insertTwinDeviceYhj(twinDeviceYhj);
    }

    /**
     * 修改印花机设备管理
     *
     * @param twinDeviceYhj 印花机设备管理
     * @return 结果
     */
    @Override
    public int updateTwinDeviceYhj(TwinDeviceYhj twinDeviceYhj) {
        return twinDeviceYhjMapper.updateTwinDeviceYhj(twinDeviceYhj);
    }

    /**
     * 批量删除印花机设备管理
     *
     * @param deviceIds 需要删除的印花机设备管理主键
     * @return 结果
     */
    @Override
    public int deleteTwinDeviceYhjByDeviceIds(Long[] deviceIds) {
        return twinDeviceYhjMapper.deleteTwinDeviceYhjByDeviceIds(deviceIds);
    }

    /**
     * 删除印花机设备管理信息
     *
     * @param deviceId 印花机设备管理主键
     * @return 结果
     */
    @Override
    public int deleteTwinDeviceYhjByDeviceId(Long deviceId) {
        return twinDeviceYhjMapper.deleteTwinDeviceYhjByDeviceId(deviceId);
    }
}
